TensorBinaryWriter class

Constructors

TensorBinaryWriter(DataWriter dataWriter)

Properties

dataWriter → DataWriter
final
hashCode int
The hash code for this object.
no setterinherited
q16 Q16Quantizer
final
q8 Q8Quantizer
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeTensor(Float32List tensor, QuantType type) Future<void>
writeTensorBF16(Float32List tensor) → void
writeTensorBF16H(Float32List tensor) → void
writeTensorFP32(Float32List tensor) → void
writeTensorFromRepo(TensorRepository repo, String tensorName, QuantType type) Future<void>
writeTensorQ16(Float32List tensor) → void
writeTensorQ16PerBlock(Float32List tensor) → void
writeTensorQ8(Float32List tensor) → void
writeTensorQ8PerBlock(Float32List tensor) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited